// Enforce use of a strict operating context.
'use strict';

// Define handler for this plugin.
const plugin = (nodewrite, options, nextPlugin) => {

  // Use provided plugin options.
  const { container, namespace } = options;

  // Resolve dependencies from app container.
  container.resolve((peers) => {

    // Peer dependencies required before trying to load this plugin.
    nodewrite.dependency(peers(__dirname), (server, nextDependency) => {

      // Define methods used internally by this plugin.
      const internals = {
        // Register plugin controllers.
        controllers: {
          admin: require('./controllers/admin')(server),
          api: require('./controllers/api')(server)
        }
      };

      // Register plugin views.
      // Register plugin views.
      server.registerPluginAssets(__dirname);

      // Attach plugin route(s) to admin server.
      server.select('admin').route([
        {
          method: 'GET',
          path: '/instance',
          config: {
            id: namespace.admin('index'),
            handler: internals.controllers.admin.index
          }
        }
      ]);

      // Attach plugin route(s) to api server.
      server.select('api').route([
        {
          method: 'GET',
          path: '/instance',
          handler: internals.controllers.api.get
        },
        {
          method: 'PUT',
          path: '/instance',
          handler: internals.controllers.api.update
        }
      ]);

      // Finished with peer dependency registration.
      nextDependency();

    });

    // Finished with plugin registration.
    nextPlugin();

  });

};

// Attach plugin attributes.
plugin.attributes = {
  pkg: require('./package.json')
};

// Expose plugin on module's register property.
exports.register = plugin;
